@@ -1,12 +1,13 @@
 package Yukki::Model::File;
 {
-  $Yukki::Model::File::VERSION = '0.132160';
+  $Yukki::Model::File::VERSION = '0.140290';
 }
 use 5.12.1;
 use Moose;
 
 extends 'Yukki::Model';
 
+use Class::Load;
 use Digest::SHA1 qw( sha1_hex );
 use Number::Bytes::Human qw( format_bytes );
 use LWP::MediaTypes qw( guess_media_type );
@@ -304,7 +305,7 @@ sub diff {
 sub file_preview {
     my ($self, %params) = @_;
 
-    Class::MOP::load_class('Yukki::Model::FilePreview');
+    Class::Load::load_class('Yukki::Model::FilePreview');
     return Yukki::Model::FilePreview->new(
         %params,
         app        => $self->app,
@@ -346,7 +347,7 @@ Yukki::Model::File - the model for loading and saving files in the wiki
 
 =head1 VERSION
 
-version 0.132160
+version 0.140290
 
 =head1 SYNOPSIS
 
@@ -557,7 +558,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Qubling Software LLC.
+This software is copyright (c) 2014 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
